log using demcap_table2, replace

clear
set more off
set mem 100m
set matsize 400

use demcap_tables2_3.dta

* There are three 'democratic capital' variables in the dataset:
* 	demcap_delta94
* 	demcap_delta99
* 	demcap_br
* in the estimations below, the generic variable 'demcap' is used throughout. It is redefined
* a number of times, so that it corresponds with the appropriate 'democratic capital' variable.
* Generate 'generic' demcap variable:
gen demcap = .


***************
*** Table 2 ***
***************
* From Table2_march8_simple.do

* Redefine 'generic' demcap variable
replace demcap = demcap_delta94

************
* Column 1 *
************

probit end_dem demcap closdem_cont_dist llyp if end_dem <2, robust 

* Likelihood ratio test
xtlogit end_dem demcap closdem_cont_dist llyp if end_dem <2, i(ctycode)

************
* Column 2 *
************

probit end_dic demcap closdem_cont_dist llyp if end_dic <2, robust

* Likelihood ratio test
xtlogit end_dic demcap closdem_cont_dist llyp if end_dic <2, i(ctycode)

*************************************************************************
*************************************************************************
* From Table2_march8_full.do

* Redefine demcap for columns 3 and 4
replace demcap = demcap_delta99

************
* Column 3 *
************

probit end_dem demcap closdem_cont_dist llyp polity_start exconst_start  ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me period period_sq if end_dem <2, robust

* Likelihood ratio test
xtlogit end_dem demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me period period_sq if end_dem <2, i(ctycode)

************
* Column 4 *
************

probit end_dic demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me period period_sq if end_dic <2, robust

* Likelihood ratio test
xtlogit end_dic demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_esp c_uk_mt m5dic africa asia_me period period_sq if end_dic <2, i(ctycode)

*************************************************************************
*************************************************************************
* From Table2_march8_br.do

* Redefine demcap for columns 5 and 6 (Boix-Rosato data)
replace demcap = demcap_br

************
* Column 5 *
************

probit end_dem_br demcap closdem_cont_dist llyp start_dem_br ///
war lwar l_soc c_uk_mt c_esp m5dic_br africa asia_me period period_sq if end_dem_br <2, robust

* Likelihood ratio test
xtlogit end_dem_br demcap closdem_cont_dist llyp start_dem_br ///
war lwar l_soc c_uk_mt c_esp m5dic_br africa asia_me period period_sq if end_dem_br <2, i(ctycode)

************
* Column 6 *
************

probit end_dic_br demcap closdem_cont_dist llyp start_dem_br ///
war lwar l_soc c_uk_mt c_esp m5dic_br africa asia_me period period_sq if end_dic_br <2, robust

* Likelihood ratio test
xtlogit end_dic_br demcap closdem_cont_dist llyp start_dem_br ///
war lwar l_soc c_esp c_uk_mt m5dic_br africa asia_me period period_sq if end_dic_br <2, i(ctycode)

*************************************************************************
*************************************************************************
* From Table3_march8_humcap.do

* Redefine demcap:
replace demcap = demcap_delta94


************
* Column 7 *
************

probit end_dem demcap closdem_cont_dist llyp humancapital if end_dem <2, robust

* Likelihood ratio test
xtlogit end_dem demcap closdem_cont_dist llyp humancapital  if end_dem <2, i(ctycode)

************
* Column 8 *
************

probit end_dic demcap closdem_cont_dist llyp humancapital if end_dic <2, robust

* Likelihood ratio test
xtlogit end_dic demcap closdem_cont_dist llyp humancapital if end_dic <2, i(ctycode)

log close

*************************************************************************
*************************************************************************

log using demcap_table3, replace

***************
*** Table 3 ***
***************

* From Table2_april8_country_fixed_effects.do

* Redefine demcap:
replace demcap = demcap_delta99


************
* Column 1 *
************

xtlogit end_dem demcap closdem_cont_dist llyp war lwar period period_sq if end_dem <2, fe i(ctycode)
* Pseudo r-square:
disp "Pseudo r-square: " e(r2_p)

************
* Column 2 *
************

xtlogit end_dic demcap closdem_cont_dist llyp war lwar period period_sq if end_dic <2,  fe i(ctycode)
* Pseudo r-square:
disp "Pseudo r-square: " e(r2_p)

*************************************************************************
*************************************************************************

************
* Column 3 *
************

probit end_dem demcap_cur demcap_past closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me period period_sq if end_dem <2, robust

* Likelihood ratio test:
xtlogit end_dem demcap_cur demcap_past closdem_cont_dist llyp polity_start exconst_start m5dic ///
war lwar l_soc c_uk_mt c_esp africa asia_me period period_sq if end_dem <2, i(ctycode)

************
* Column 4 *
************

probit end_dic demcap closdem_cont_dist llyp durdic polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me period period_sq if end_dic <2, robust

* Likelihood ratio tets:
xtlogit end_dic demcap closdem_cont_dist llyp durdic polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me period period_sq if end_dic <2, i(ctycode)

*************************************************************************
*************************************************************************

* Generate time dummies for columns (5)--(8) (from five_year_dummy.do)
* yearly dummies:

tabulate year, gen(dumyear)

* five-year dummies

g dum1 = sum(dumyear1-dumyear5)
g dum2 = sum(dumyear6-dumyear10)

g dum3 = sum(dumyear11-dumyear15)
g dum4 = sum(dumyear16-dumyear20)

g dum5 = sum(dumyear21-dumyear25)
g dum6 = sum(dumyear26-dumyear30)

g dum7 = sum(dumyear31-dumyear35)
g dum8 = sum(dumyear36-dumyear40)

g dum9 = sum(dumyear41-dumyear45)
g dum10 = sum(dumyear46-dumyear50)

g dum11 = sum(dumyear51-dumyear55)
g dum12 = sum(dumyear56-dumyear60)

g dum13 = sum(dumyear61-dumyear65)
g dum14 = sum(dumyear66-dumyear70)

g dum15 = sum(dumyear71-dumyear75)
g dum16 = sum(dumyear76-dumyear80)

g dum17 = sum(dumyear81-dumyear85)
g dum18 = sum(dumyear86-dumyear90)

g dum19 = sum(dumyear91-dumyear95)
g dum20 = sum(dumyear96-dumyear100)

g dum21 = sum(dumyear101-dumyear105)
g dum22 = sum(dumyear106-dumyear110)

g dum23 = sum(dumyear111-dumyear115)
g dum24 = sum(dumyear116-dumyear120)

g dum25 = sum(dumyear121-dumyear125)
g dum26 = sum(dumyear126-dumyear130)

g dum27 = sum(dumyear131-dumyear135)
g dum28 = sum(dumyear136-dumyear140)

g dum29 = sum(dumyear141-dumyear145)
g dum30 = sum(dumyear146-dumyear150)

g dum31 = sum(dumyear151-dumyear155)
g dum32 = sum(dumyear156-dumyear160)

g dum33 = sum(dumyear161-dumyear165)
g dum34 = sum(dumyear166-dumyear170)

g dum35 = sum(dumyear171-dumyear175)
g dum36 = sum(dumyear176-dumyear180)

g dum37 = sum(dumyear181-dumyear185)
g dum38 = sum(dumyear186-dumyear190)

g dum39 = sum(dumyear191-dumyear195)
g dum40 = sum(dumyear196-dumyear201)


* 10-year dummies

g y1 = sum(dum1-dum2)
g y2 = sum(dum3-dum4)
g y3 = sum(dum5-dum6)
g y4 = sum(dum7-dum8)
g y5 = sum(dum9-dum10)
g y6 = sum(dum11-dum12)
g y7 = sum(dum13-dum14)
g y8 = sum(dum15-dum16)
g y9 = sum(dum17-dum18)
g y10 = sum(dum19-dum20)

g y11 = sum(dum21-dum22)
g y12 = sum(dum23-dum24)
g y13 = sum(dum25-dum26)
g y14 = sum(dum27-dum28)
g y15 = sum(dum29-dum30)
g y16 = sum(dum31-dum32)
g y17 = sum(dum33-dum34)
g y18 = sum(dum35-dum36)
g y19 = sum(dum37-dum38)
g y20 = sum(dum39-dum40)


* From Table2_april8_timedum.do

************
* Column 5 *
************

logit end_dem demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me y1-y20 if end_dem <2, robust

* Likelihood ratio test
xtlogit end_dem demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me y1-y20 if end_dem <2, i(ctycode)

************
* Column 6 *
************

logit end_dic demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me y1-y20 if end_dic <2, robust

* Likelihood ratio test
xtlogit end_dic demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_esp c_uk_mt m5dic africa asia_me y1-y20 if end_dic <2, i(ctycode)

*************************************************************************
*************************************************************************

************
* Column 7 *
************

logit end_dem demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me dum1-dum40 if end_dem <2, robust

* Likelihood ratio test
xtlogit end_dem demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me dum1-dum40 if end_dem <2, i(ctycode)


************
* Column 8 *
************

logit end_dic demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_uk_mt c_esp m5dic africa asia_me dum1-dum40 if end_dic <2, robust

* Likelihood ratio test
xtlogit end_dic demcap closdem_cont_dist llyp polity_start exconst_start ///
war lwar l_soc c_esp c_uk_mt m5dic africa asia_me dum1-dum40 if end_dic <2, i(ctycode)

*************************************************************************
*************************************************************************

* From Table2_april8_country_year_fixed effects.do

************
* Column 9 *
************

xtlogit end_dic demcap closdem_cont_dist llyp war lwar dumyear1-dumyear200 if end_dic <2,  fe i(ctycode)


log close
